package com.yanzhu.jh.trouble.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.trouble.domain.SmzSspMarks;
import com.yanzhu.jh.trouble.service.ISmzSspMarksService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 质量留痕Controller
 * 
 * @author JiangYuQi
 * @date 2023-07-28
 */
@RestController
@RequestMapping("/trouble/sspMarks")
public class SmzSspMarksController extends BaseController
{
    @Autowired
    private ISmzSspMarksService smzSspMarksService;

    /**
     * 查询质量留痕列表
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspMarks:list')")
    @GetMapping("/list")
    public TableDataInfo list(SmzSspMarks smzSspMarks)
    {
        startPage();
        List<SmzSspMarks> list = smzSspMarksService.selectSmzSspMarksList(smzSspMarks);
        return getDataTable(list);
    }

    /**
     * 导出质量留痕列表
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspMarks:export')")
    @Log(title = "质量留痕", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SmzSspMarks smzSspMarks)
    {
        List<SmzSspMarks> list = smzSspMarksService.selectSmzSspMarksList(smzSspMarks);
        ExcelUtil<SmzSspMarks> util = new ExcelUtil<SmzSspMarks>(SmzSspMarks.class);
        util.exportExcel(response, list, "质量留痕数据");
    }

    /**
     * 获取质量留痕详细信息
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspMarks:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(smzSspMarksService.selectSmzSspMarksById(id));
    }

    /**
     * 新增质量留痕
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspMarks:add')")
    @Log(title = "质量留痕", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SmzSspMarks smzSspMarks)
    {
        return toAjax(smzSspMarksService.insertSmzSspMarks(smzSspMarks));
    }

    /**
     * 修改质量留痕
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspMarks:edit')")
    @Log(title = "质量留痕", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SmzSspMarks smzSspMarks)
    {
        return toAjax(smzSspMarksService.updateSmzSspMarks(smzSspMarks));
    }

    /**
     * 删除质量留痕
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspMarks:remove')")
    @Log(title = "质量留痕", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(smzSspMarksService.deleteSmzSspMarksByIds(ids));
    }
}
